@@ -16,12 +16,81 @@ from PIL import Image, ImageDraw, ImageFont
 import re
 
 
+'''
+    List of methods anailable
+    
+    xml2hdf()
+        converts scalar_data xml files to a more efficient hdf file
+    
+    spec_map()
+        takes experiment png and adds boxes where the measurements were taken.
+        Saves to new file
+        
+    read()
+        imports all hdf data scalar_data files
+    
+    parameters()
+        imports measurement info including: original NID filename,
+        spot number, spring constant, deflection sensitivity, map size (um),
+        map size (pixels), data points, ramp length, ramp speed, and max force
+        
+    stats(spots)
+        calculates general statistics of the data
+            spot (integer) or aggregated spots (list)
+        
+    channelData(spots, channel, direction, fill_empty=False)
+        returns data for a specific
+            spot (integer) or spots aggregated (list),
+            channel (string: 'E-Modul', 'Minimum', etc.),
+            direction (bool: backward=True), and
+            fill_empty=False (bool: fills missing data with NaN)
+    
+    spotData(spots)
+        returns data all data for a specific
+            spot (integer) or spots (list)
+
+    image(spot, channel, direction, lim=None, scale=None, label=None, cmap=cm.afmhot, kwargs)
+        plots a force-volume map of the data from a specific
+            spot (integer),
+            channel (string: 'E-Modul', 'Minimum', etc.),
+            direction (bool: backward=True),
+            lim=None (float: limit the data)
+            scale=None (float: scale the data)
+            label=None (string: the label (i.e. unit) of the colorbar)
+            cmap=cm.afmhot (pyplot colormap: the colormap to use)
+            kwargs (extra keyed arguments that are passed on to pyplot)
+
+    hist(spots, channel, direction, lim=None, scale=None, label=None, cmap=cm.afmhot, kwargs)
+        plots a histogram of the data from specific
+            spot (integer) or spots aggregated (list),
+            channel (string: 'E-Modul', 'Minimum', etc.),
+            direction (bool: backward=True),
+            lim=None (float: limit the data)
+            scale=None (float: scale the data)
+            label=None (string: the label (i.e. unit) of the x axis)
+            cmap=cm.afmhot (pyplot colormap: the colormap to use)
+            kwargs (extra keyed arguments that are passed on to pyplot)
+            
+    gaussianMix(spots, channel, direction, number=1, lim=None, scale=None)
+        tries to identify different populations in a data set using gaussian mixture
+        algorithm and returns means and weights of mixture.  Works okay, need
+        to add ability to input first guesses
+            spot (integer) or spots aggregated (list),
+            channel (string: 'E-Modul', 'Minimum', etc.),
+            direction (bool: backward=True),
+            number=1 (integer: number of populations)
+            lim=None (float: limit the data)
+            scale=None (float: scale the data)
+'''
+
+
 class ANA():
     def __init__(self, directory):
         self.directory = directory
-        self.files = glob(self.directory + '\\scalar*.h5')
-        self.files.sort(key=self._natural_keys)
-
+        self._filelist()
+        if not self.files:
+            print('scalar_data files not in HDF format.  Run xml2hdf to convert.')
+            
         self.parameters()
 
     def spec_map(self):
@@ -79,8 +148,11 @@ class ANA():
         deflection = [float(x.text) * 1e9/10 for x in root.find('deflection_sensitivities_').findall('element')]
 
         mapSz = (np.array(xEnd) - np.array(xStart)) * 1e6
+        
+        spots = np.arange(len(filename)) + 1
 
         self.param = pd.DataFrame(data={'FileName': filename,
+                                        'Spot': spots,
                                         'SpringConstant': springK,
                                         'DeflSens': deflection,
                                         'MapSize': mapSz,
@@ -153,6 +225,30 @@ class ANA():
 
             df.to_hdf(f + '.h5', key='df')
 
+    def channelData(self, spots, channel, backward, fill_empty=False):
+        d = self.spotData(spots)
+        dd = d[(d['Channel'] == channel) & (d['Backward'] == backward)]
+        if fill_empty:
+            sz = self.param.MapPixSize[spots - 1]
+        
+            ar = np.zeros(sz * sz) * np.nan
+            ar[dd.Line.values] = dd.Value.values
+            dd = pd.DataFrame({'Value': ar})
+        return dd
+    
+    def spotData(self, spots):
+        if isinstance(spots, list):
+            if len(spots) > 1:
+                spots = self.data.Spot.isin(spots)
+                d = pd.concat([x for x in self.data[spots].Data], axis=0)
+            else:
+                spots = self.data.Spot.isin(spots)
+                d = self.data[spots]
+        else:
+            spots = self.data.Spot.isin([spots])
+            d = self.data[spots].Data.iloc[0]
+        return d
+
     def image(self, spot, channel, backward,
               lim=None, scale=None, label=None, cmap=cm.afmhot,
               **kwargs):
@@ -173,14 +269,14 @@ class ANA():
         ar = ar.reshape((sz, sz)).copy()
         ar[::2] = np.fliplr(ar[::2])
         
-        ar=np.fliplr(ar)
+        ar = np.fliplr(ar)
 
         mSize = self.param.MapSize[spot - 1]
         plt.imshow(ar, origin='bottomleft', extent=(0, mSize, 0, mSize), cmap=cmap, **kwargs)
         if lim:
             plt.clim(vmax=lim)
-        plt.xlabel('[$\mu$m]')
-        plt.ylabel('[$\mu$m]')
+        plt.xlabel(r'[$\mu$m]')
+        plt.ylabel(r'[$\mu$m]')
         plt.title(channel)
         cbar = plt.colorbar()
         cbar.set_label(label, rotation=-90, va="bottom")
@@ -231,17 +327,10 @@ class ANA():
         fits = pd.DataFrame({'mean': m, 'weight': w})
         fits = fits.sort_values('mean').reindex()
         return fits
-    
-    def channelData(self, spots, channel, backward, fill_empty=False):
-        d = self.spotData(spots)
-        dd = d[(d['Channel'] == channel) & (d['Backward'] == backward)]
-        if fill_empty:
-            sz = self.param.MapPixSize[spots - 1]
-        
-            ar = np.zeros(sz*sz) * np.nan
-            ar[dd.Line.values] = dd.Value.values
-            dd = pd.DataFrame({'Value': ar})
-        return dd
+
+    def _filelist(self):
+        self.files = glob(self.directory + '\\scalar*.h5')
+        self.files.sort(key=self._natural_keys)
     
     # sorts list numerically
     def _atoi(self, text):
@@ -250,28 +339,18 @@ class ANA():
     def _natural_keys(self, text):
         return [self._atoi(c) for c in re.split(r'(\d+)', text)]
 
-    def spotData(self, spots):
-        if isinstance(spots, list):
-            if len(spots) > 1:
-                spots = self.data.Spot.isin(spots)
-                d = pd.concat([x for x in self.data[spots].Data], axis=0)
-            else:
-                spots = self.data.Spot.isin(spots)
-                d = self.data[spots]
-        else:
-            spots = self.data.Spot.isin([spots])
-            d = self.data[spots].Data.iloc[0]
-        return d
-
 
 if __name__ == "__main__":
     from matplotlib import cm
-    directory = r'0217_A\default'
+    directory = r'test'
     ana = ANA(directory)
-    # ana.xml2hdf()
+    
     ana.read()
-    ana.hist(1, 'E-Modul', True, scale=1e9, lim=3, label='[GPa]', bins=128)
-    plt.show()
+
     ana.image(1, 'E-Modul', True, scale=1e9, lim=3, label='[GPa]', cmap=cm.afmhot)
     plt.show()
-    r = ana.gaussianMix(3, 'E-Modul', True, 2)
+    ana.hist(1, 'E-Modul', True, scale=1e9, lim=3, label='[GPa]', bins=128)
+    plt.show()
+
+    r = ana.gaussianMix(1, 'E-Modul', True, 3, lim=3, scale=1e9)
+    print(r)
